# OSS-Lag: Open Source Software Lag Dataset

This repository contains code to build a dataset measuring technical lag and
abandonment of open source packages across multiple Linux distributions.


## Installation

You can install from PyPI using pip:

```bash
pip install osslag
```

## Usage

Run the cli tool with `--help` to see available commands and options:

```bash
osslag --help
```
